<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>GnomeHotkeyFactory</name>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="29"/>
        <source>Gnome Hotkey Plugin</source>
        <translation>Πρόσθετο συντομεύσεων Gnome</translation>
    </message>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="50"/>
        <source>About Gnome Hotkey Plugin</source>
        <translation>Σχετικά με το πρόσθετο συντομεύσεων Gnome</translation>
    </message>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="51"/>
        <source>Qmmp Gnome Hotkey Plugin</source>
        <translation>Qmmp πρόσθετο συντομεύσεων Gnome</translation>
    </message>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support of the GNOME/Cinnamon hotkeys</source>
        <translation>Αυτό το πρόσθετο προσθέτει υποστήριξη συντομεύσεων για GNOME/Cinnamon</translation>
    </message>
    <message>
        <location filename="../gnomehotkeyfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
